@@ -14,7 +14,7 @@ from larray.core.group import (Group, LGroup, IGroup, IGroupMaker, _to_tick, _to
                                _contain_group_ticks, _seq_group_to_name)
 from larray.util.oset import *
 from larray.util.misc import (basestring, PY2, unicode, long, duplicates, array_lookup2, ReprString, index_by_id,
-                              renamed_to)
+                              renamed_to, common_type)
 
 __all__ = ['Axis', 'AxisCollection', 'X', 'x']
 
@@ -332,6 +332,72 @@ class Axis(ABCAxis):
         else:
             return split_axes
 
+    def insert(self, new_labels, before=None, after=None):
+        """
+        Return a new axis with `new_labels` inserted before `before` or after `after`.
+
+        Parameters
+        ----------
+        new_labels : scalar, tuple/list/array of scalars, Group or Axis
+            New label(s) to append to the axis.
+        before : scalar or Group, optional
+            Label or group before which to insert `new_labels`.
+        after : scalar or Group, optional
+            Label or group after which to insert `new_labels`.
+
+        Returns
+        -------
+        Axis
+            A copy of the axis with the new labels inserted.
+
+        Examples
+        --------
+        >>> time = Axis([2007, 2009], 'time')
+        >>> time.insert(2008, before=2009)
+        Axis([2007, 2008, 2009], 'time')
+        >>> time.insert(2008, after=2007)
+        Axis([2007, 2008, 2009], 'time')
+        >>> time.insert(2008, before=time.i[1])
+        Axis([2007, 2008, 2009], 'time')
+        >>> time.insert(2008, after=time.i[0])
+        Axis([2007, 2008, 2009], 'time')
+        >>> b = Axis(['b1', 'b2'], 'b')
+        >>> b.insert('b1.5', before='b2')
+        Axis(['b1', 'b1.5', 'b2'], 'b')
+        >>> b.insert(['b1.1', 'b1.2'], before='b2')
+        Axis(['b1', 'b1.1', 'b1.2', 'b2'], 'b')
+        >>> c = Axis(['c1', 'c2'], 'c')
+        >>> b.insert(c, before='b2')
+        Axis(['b1', 'c1', 'c2', 'b2'], 'b')
+        """
+        if sum([before is not None, after is not None]) != 1:
+            raise ValueError("must specify exactly one of before or after")
+        if before is not None:
+            before = self.index(before)
+        else:
+            assert after is not None
+            before = self.index(after) + 1
+
+        if isinstance(new_labels, Axis):
+            new_labels = new_labels.labels
+        elif isinstance(new_labels, Group):
+            new_labels = new_labels.eval()
+        else:
+            if np.isscalar(new_labels):
+                new_labels = [new_labels]
+            new_labels = np.asarray(new_labels)
+
+        current_labels = self.labels
+        labels_type = common_type((current_labels, new_labels))
+        if labels_type is object:
+            # astype always copies, while asarray only copies if necessary
+            current_labels = np.asarray(current_labels, dtype=object)
+            new_labels = np.asarray(new_labels, dtype=object)
+
+        # not using np.insert to avoid inserted string labels being truncated (because of current_labels.dtype)
+        res_labels = np.concatenate((current_labels[:before], new_labels, current_labels[before:]))
+        return Axis(res_labels, self.name)
+
     @property
     def iswildcard(self):
         return self._iswildcard
@@ -675,7 +741,7 @@ class Axis(ABCAxis):
         # object kind can match anything
         return key_kind == label_kind or key_kind == 'O' or label_kind == 'O' or py2_str_match
 
-    def translate(self, key, bool_passthrough=True):
+    def index(self, key, bool_passthrough=True):
         """
         Translates a label key to its numerical index counterpart.
 
@@ -698,9 +764,9 @@ class Axis(ABCAxis):
         Examples
         --------
         >>> people = Axis(['John Doe', 'Bruce Wayne', 'Bruce Willis', 'Waldo', 'Arthur Dent', 'Harvey Dent'], 'people')
-        >>> people.translate('Waldo')
+        >>> people.index('Waldo')
         3
-        >>> people.translate(people.matching('Bruce'))
+        >>> people.index(people.matching('Bruce'))
         array([1, 2])
         """
         mapping = self._mapping
@@ -784,7 +850,7 @@ class Axis(ABCAxis):
                 return array_lookup2(key, self._sorted_keys, self._sorted_values)
         elif isinstance(key, ABCLArray):
             from .array import LArray
-            return LArray(self.translate(key.data), key.axes)
+            return LArray(self.index(key.data), key.axes)
         else:
             # the first mapping[key] above will cover most cases.
             # This code path is only used if the key was given in "non normalized form"
@@ -796,6 +862,8 @@ class Axis(ABCAxis):
                 # print("diff dtype", )
                 raise KeyError(key)
 
+    translate = renamed_to(index, 'translate')
+
     # FIXME: remove id
     @property
     def id(self):
@@ -946,7 +1014,7 @@ class Axis(ABCAxis):
             assert len(old) == len(new)
         # using object dtype because new labels length can be larger than the fixed str length in the self.labels array
         labels = self.labels.astype(object)
-        indices = self.translate(old)
+        indices = self.index(old)
         labels[indices] = new
         return Axis(labels, self.name)
 
@@ -1644,7 +1712,7 @@ class AxisCollection(object):
         for i, axis in enumerate(axes):
             local_axis = self.get_by_pos(axis, i)
             if not local_axis.iscompatible(axis):
-                raise ValueError("incompatible axes:\n%r\nvs\n%r" % (axis, local_axis))
+                raise ValueError("incompatible axes:\n{!r}\nvs\n{!r}".format(axis, local_axis))
 
     def extend(self, axes, validate=True, replace_wildcards=False):
         """
@@ -1993,7 +2061,7 @@ class AxisCollection(object):
         (slice(None, None, None), 1, 2)
         """
         assert len(key) == len(self)
-        return tuple(axis.translate(axis_key) for axis_key, axis in zip(key, self))
+        return tuple(axis.index(axis_key) for axis_key, axis in zip(key, self))
 
     @property
     def labels(self):
@@ -2515,7 +2583,7 @@ class AxisReference(ABCAxisReference, ExprNode, Axis):
         self._labels = None
         self._iswildcard = False
 
-    def translate(self, key):
+    def index(self, key):
         raise NotImplementedError("an AxisReference (X.) cannot translate labels")
 
     def __repr__(self):
