@@ -280,15 +280,34 @@ if xw is not None:
         return slice(s.start if s.start is not None else 0, s.stop if s.stop is not None else length, s.step)
 
 
-    def _concrete_key(key, shape):
+    def _concrete_key(key, obj, ndim=2):
+        """Expand key to ndim and replace None in slices start/stop bounds by 0 or obj.shape[corresponding_dim]
+        respectively.
+
+        Parameters
+        ----------
+        key : scalar, slice or tuple
+            input key
+        obj : object
+            any object with a 'shape' attribute.
+        ndim : int
+            number of dimensions to expand to. We could use len(obj.shape) instead but we avoid it to not trigger
+            obj.shape, which can be expensive in the case of a sheet with blank cells after the data.
+        """
         if not isinstance(key, tuple):
             key = (key,)
 
-        if len(key) < len(shape):
-            key = key + (slice(None),) * (len(shape) - len(key))
+        if len(key) < ndim:
+            key = key + (slice(None),) * (ndim - len(key))
 
-        # We do not use slice(*k.indices(length)) because it also clips bounds which exceed the length, which we do not
-        # want in this case (see issue #273).
+        # only compute shape if necessary because it can be expensive in some cases
+        if any(isinstance(k, slice) and k.stop is None for k in key):
+            shape = obj.shape
+        else:
+            shape = (None, None)
+
+        # We use _fill_slice instead of slice(*k.indices(length)) because the later also clips bounds which exceed
+        # the length and we do NOT want to do that in this case (see issue #273).
         return [_fill_slice(k, length) if isinstance(k, slice) else k
                 for k, length in zip(key, shape)]
 
@@ -305,7 +324,7 @@ if xw is not None:
             if isinstance(key, string_types):
                 return Range(self, key)
 
-            row, col = _concrete_key(key, self.shape)
+            row, col = _concrete_key(key, self)
             if isinstance(row, slice) or isinstance(col, slice):
                 row1, row2 = (row.start, row.stop) if isinstance(row, slice) else (row, row + 1)
                 col1, col2 = (col.start, col.stop) if isinstance(col, slice) else (col, col + 1)
@@ -320,20 +339,63 @@ if xw is not None:
 
         @property
         def shape(self):
-            # include top-left empty rows/columns
+            """
+            shape of sheet including top-left empty rows/columns but excluding bottom-right ones.
+            """
             from xlwings.constants import Direction as xldir
-            used = self.xw_sheet.api.UsedRange
-            last_row = used.Row + used.Rows.Count
-            last_col = used.Column + used.Columns.Count
-            for last_used_row in range(last_row, 0, -1):
-                left_cell = used.Cells(last_used_row, last_col + 1).End(xldir.xlToLeft)
-                if left_cell.Column > 1 or left_cell.Value is not None:
-                    break
-            for last_used_col in range(last_col, 0, -1):
-                up_cell = used.Cells(last_row + 1, last_used_col).End(xldir.xlUp)
-                if up_cell.Row > 1 or up_cell.Value is not None:
-                    break
-            return (last_used_row, last_used_col)
+
+            sheet = self.xw_sheet.api
+            used = sheet.UsedRange
+            first_row = used.Row
+            first_col = used.Column
+            last_row = first_row + used.Rows.Count - 1
+            last_col = first_col + used.Columns.Count - 1
+            last_cell = sheet.Cells(last_row, last_col)
+
+            # fast path for sheets with a non blank bottom-right value
+            if last_cell.Value is not None:
+                return last_row, last_col
+
+            last_row_used = last_cell.End(xldir.xlToLeft).Value is not None
+            last_col_used = last_cell.End(xldir.xlUp).Value is not None
+
+            # fast path for sheets where last row and last col are not entirely blank
+            if last_row_used and last_col_used:
+                return last_row, last_col
+            else:
+                LEFT, UP = xldir.xlToLeft, xldir.xlUp
+
+                def line_length(row, col, direction):
+                    last_cell = sheet.Cells(row, col)
+                    if last_cell.Value is not None:
+                        return col if direction is LEFT else row
+                    first_cell = last_cell.End(direction)
+                    pos = first_cell.Column if direction is LEFT else first_cell.Row
+                    return pos - 1 if first_cell.Value is None else pos
+
+                if last_row < last_col:
+                    if last_row_used or last_row == 1:
+                        max_row = last_row
+                    else:
+                        for max_row in range(last_row - 1, first_row - 1, -1):
+                            if line_length(max_row, last_col, LEFT) > 0:
+                                break
+                    if last_col_used or last_col == 1:
+                        max_col = last_col
+                    else:
+                        max_col = max(line_length(row, last_col, LEFT) for row in range(first_row, max_row + 1))
+                else:
+                    if last_col_used or last_col == 1:
+                        max_col = last_col
+                    else:
+                        for max_col in range(last_col - 1, first_col - 1, -1):
+                            if line_length(last_row, max_col, UP) > 0:
+                                break
+                    if last_row_used or last_row == 1:
+                        max_row = last_row
+                    else:
+                        max_row = max(line_length(last_row, col, UP) for col in range(first_col, max_col + 1))
+                return max_row, max_col
 
         @property
         def ndim(self):
@@ -404,7 +466,7 @@ if xw is not None:
             assert not isinstance(key, string_types)
             row_offset = self.xw_range.row1 - 1
             col_offset = self.xw_range.col1 - 1
-            row, col = _concrete_key(key, self.xw_range.shape)
+            row, col = _concrete_key(key, self.xw_range)
             row = slice(row.start + row_offset, row.stop + row_offset) if isinstance(row, slice) else row + row_offset
             col = slice(col.start + col_offset, col.stop + col_offset) if isinstance(col, slice) else col + col_offset
             return row, col
