@@ -106,8 +106,8 @@ class TestAxis(TestCase):
         # an axis with labels having the object dtype
         a = Axis(np.array(["a0", "a1"], dtype=object), 'a')
 
-        self.assertEqual(a.translate('a1'), 1)
-        self.assertEqual(a.translate('a1 >> A1'), 1)
+        self.assertEqual(a.index('a1'), 1)
+        self.assertEqual(a.index('a1 >> A1'), 1)
 
     def test_getitem_lgroup_keys(self):
         def group_equal(g1, g2):
