@@ -11,7 +11,7 @@ except ImportError:
     xw = None
 
 from larray import ndtest, ndrange, larray_equal, open_excel, aslarray
-from larray.io import excel
+from larray.inout import excel
 
 
 @pytest.mark.skipif(xw is None, reason="xlwings is not available")
@@ -40,7 +40,7 @@ class TestWorkbook(object):
 
     def test_repr(self):
         with open_excel(visible=False) as wb:
-            assert re.match('<larray.io.excel.Workbook \[Book\d+\]>', repr(wb))
+            assert re.match('<larray.inout.excel.Workbook \[Book\d+\]>', repr(wb))
 
     def test_getitem(self):
         with open_excel(visible=False) as wb:
@@ -85,6 +85,12 @@ class TestWorkbook(object):
                     wb2['sheet1'] = wb['sheet1']
                 assert e_info.value.args[0] == "cannot copy a sheet from one instance of Excel to another"
 
+            # group key
+            arr = ndtest((3, 3))
+            for label in arr.b:
+                wb[label] = arr[label].dump()
+                assert larray_equal(wb[label].load(), arr[label])
+
     def test_delitem(self):
         with open_excel(visible=False) as wb:
             wb['sheet1'] = 'sheet1 content'
@@ -160,7 +166,7 @@ class TestSheet(object):
     def test_repr(self):
         with open_excel(visible=False) as wb:
             sheet = wb[0]
-            assert re.match('<larray.io.excel.Sheet \[Book\d+\]Sheet1>', repr(sheet))
+            assert re.match('<larray.inout.excel.Sheet \[Book\d+\]Sheet1>', repr(sheet))
 
 
 @pytest.mark.skipif(xw is None, reason="xlwings is not available")
