@@ -10,7 +10,7 @@ import sys
 import operator
 import warnings
 from textwrap import wrap
-from functools import reduce
+from functools import reduce, wraps
 from itertools import product
 from collections import defaultdict
 
@@ -625,3 +625,81 @@ def renamed_to(newfunc, old_name, stacklevel=2):
         warnings.warn(msg, FutureWarning, stacklevel=stacklevel)
         return newfunc(*args, **kwargs)
     return wrapper
+
+# deprecate_kwarg is derived from pandas.util._decorators (0.21)
+def deprecate_kwarg(old_arg_name, new_arg_name, mapping=None, stacklevel=2):
+    if not isinstance(mapping, dict):
+        raise TypeError("mapping from old to new argument values must be dict!")
+    def _deprecate_kwarg(func):
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            old_arg_value = kwargs.pop(old_arg_name, None)
+            if old_arg_value is not None:
+                if mapping is not None:
+                    new_arg_value = mapping.get(old_arg_value, old_arg_value)
+                    msg = "The {old_name}={old_val!r} keyword is deprecated, use {new_name}={new_val!r} instead"\
+                        .format(old_name=old_arg_name, old_val=old_arg_value, new_name=new_arg_name,
+                                new_val=new_arg_value)
+                else:
+                    new_arg_value = old_arg_value
+                    msg = "The '{old_name}' keyword is deprecated, use '{new_name}' instead"\
+                        .format(old_name=old_arg_name, new_name=new_arg_name)
+
+                warnings.warn(msg, FutureWarning, stacklevel=stacklevel)
+                if new_arg_name in kwargs:
+                    msg = "Can only specify '{old_name}' or '{new_name}', not both"\
+                        .format(old_name=old_arg_name, new_name=new_arg_name)
+                    raise ValueError(msg)
+                else:
+                    kwargs[new_arg_name] = new_arg_value
+            return func(*args, **kwargs)
+        return wrapper
+    return _deprecate_kwarg
+
+
+def inverseop(opname):
+    comparison_ops = {
+        'lt': 'gt',
+        'gt': 'lt',
+        'le': 'ge',
+        'ge': 'le',
+        'eq': 'eq',
+        'ne': 'ne'
+    }
+    if opname in comparison_ops:
+        return comparison_ops[opname]
+    else:
+        return 'r' + opname
+
+
+_numeric_kinds = 'buifc'    # Boolean, Unsigned integer, Integer, Float, Complex
+_string_kinds = 'SU'        # String, Unicode
+_meta_kind = {k: 'str' for k in _string_kinds}
+_meta_kind.update({k: 'numeric' for k in _numeric_kinds})
+
+
+def common_type(arrays):
+    """
+    Returns a type which is common to the input arrays.
+    All input arrays can be safely cast to the returned dtype without loss of information.
+
+    Notes
+    -----
+    If list of arrays mixes 'numeric' and 'string' types, the function returns 'object' as common type.
+    """
+    arrays = [np.asarray(a) for a in arrays]
+    dtypes = [a.dtype for a in arrays]
+    meta_kinds = [_meta_kind.get(dt.kind, 'other') for dt in dtypes]
+    # mixing string and numeric => object
+    if any(mk != meta_kinds[0] for mk in meta_kinds[1:]):
+        return object
+    elif meta_kinds[0] == 'numeric':
+        return np.find_common_type(dtypes, [])
+    elif meta_kinds[0] == 'str':
+        need_unicode = any(dt.kind == 'U' for dt in dtypes)
+        # unicode are coded with 4 bytes
+        max_size = max(dt.itemsize // 4 if dt.kind == 'U' else dt.itemsize
+                       for dt in dtypes)
+        return np.dtype(('U' if need_unicode else 'S', max_size))
+    else:
+        return object
